class CorpusList extends List {
  constructor(idOrElement, options) {
    super(idOrElement, options);
    corporaSubscribers.push(this);
  }


  init() {
    var corpus;

    for (corpus of corpora) {
      this.list.appendChild(this.createCorpusElement(corpus));
    }

    this.reIndex();
    this.update();
    List.updatePagination(this);
  }


  createCorpusElement(corpus) {
    var corpusDescriptionElement, corpusElement, corpusIconElement,
        corpusTitleElement;

    corpusDescriptionElement = document.createElement("p");
    corpusDescriptionElement.dataset.key = "description";
    corpusDescriptionElement.innerText = corpus.description;
    corpusElement = document.createElement("a");
    corpusElement.classList.add("avatar", "collection-item");
    corpusElement.dataset.key = "id";
    corpusElement.dataset.value = corpus.id;
    corpusElement.href = `/corpora/${corpus.id}`;
    corpusIconElement = document.createElement("i");
    corpusIconElement.classList.add("circle", "material-icons");
    corpusIconElement.innerText = "book";
    corpusTitleElement = document.createElement("span");
    corpusTitleElement.classList.add("title");
    corpusTitleElement.dataset.key = "title";
    corpusTitleElement.innerText = corpus.title;

    corpusElement.appendChild(corpusIconElement);
    corpusElement.appendChild(corpusTitleElement);
    corpusElement.appendChild(corpusDescriptionElement);

    return corpusElement;
  }


  updateWithPatch(delta) {
    var corpusElement, key, listItem;

    for (key in delta) {
      if (key === "_t") {continue;}
      if (key.startsWith("_")) {
        this.remove("id", delta[key][0].id);
      } else if (Array.isArray(delta[key])) {
        corpusElement = this.createCorpusElement(delta[key][0]);
        listItem = this.add({"description": delta[key][0].description,
                             "title": delta[key][0].title,
                             "id": delta[key][0].id})[0];
        if (listItem.elm) {
          listItem.elm.replaceWith(corpusElement);
        }
        listItem.elm = corpusElement;
      } else {
        listItem = this.get("id", corpora[parseInt(key)].id)[0];
        if (delta[key]["description"]) {
          listItem.values({"description": delta[key]["description"][1]});
        }
        if (delta[key]["title"]) {
          listItem.values({"title": delta[key]["title"][1]});
        }
      }
    }
  }
}
